@@ -1,9 +1,9 @@
-from PyQt6.QtWidgets import QMainWindow, QMenu, QApplication, QLabel, QFileDialog, QStyleFactory, QDialog, QColorDialog, QInputDialog, QMessageBox
+from PyQt6.QtWidgets import QMainWindow, QMenu, QApplication, QFileDialog, QStyleFactory, QDialog, QColorDialog, QInputDialog, QMessageBox
 from PyQt6.Qsci import QsciScintilla, QsciScintillaBase, QsciMacro, QsciPrinter
 from PyQt6.QtGui import QIcon, QAction
 from PyQt6.QtPrintSupport import QPrintDialog
 from PyQt6.QtCore import Qt, QFileSystemWatcher, QTimer, QCoreApplication
-from jdTextEdit.Functions import executeCommand, getThemeIcon, openFileDefault, showMessageBox, saveWindowState, restoreWindowState, getTempOpenFilePath, isFilenameValid, saveProjects
+from jdTextEdit.Functions import executeCommand, getThemeIcon, openFileDefault, showMessageBox, saveWindowState, restoreWindowState, getTempOpenFilePath, isFilenameValid, saveProjects, clearStatusBar
 from jdTextEdit.gui.EditTabWidget import EditTabWidget
 from jdTextEdit.gui.SplitViewWidget import SplitViewWidget
 from jdTextEdit.EncodingList import getEncodingList
@@ -15,6 +15,7 @@ from jdTextEdit.gui.BannerWidgets.BigFileBanner import BigFileBanner
 from jdTextEdit.gui.CodeEdit import CodeEdit
 from jdTextEdit.Settings import Settings
 from jdTextEdit.Enviroment import Enviroment
+from jdTextEdit.api.StatusBarWidgetBase import StatusBarWidgetBase
 from string import ascii_uppercase
 from typing import List
 import webbrowser
@@ -34,7 +35,6 @@ class MainWindow(QMainWindow):
         self.currentMacro = None
         self.setupMenubar()
         self.splitViewWidget = SplitViewWidget(env)
-        self.setupStatusBar()
         self.toolbar = self.addToolBar("toolbar")
         self.setCentralWidget(self.splitViewWidget)
         self.autoSaveTimer = QTimer()
@@ -141,18 +141,6 @@ class MainWindow(QMainWindow):
         self.tempFileOpenWatcher.addPath(path)
         QApplication.setActiveWindow(self)
 
-    def setupStatusBar(self):
-        self.pathLabel = QLabel()
-        self.cursorPosLabel = QLabel(self.env.translate("mainWindow.statusBar.cursorPosLabel") % (1,1))
-        self.lexerLabel = QLabel()
-        self.encodingLabel = QLabel()
-        self.eolLabel = QLabel()
-        self.statusBar().addWidget(self.pathLabel)
-        self.statusBar().addPermanentWidget(self.eolLabel)
-        self.statusBar().addPermanentWidget(self.encodingLabel)
-        self.statusBar().addPermanentWidget(self.lexerLabel)
-        self.statusBar().addPermanentWidget(self.cursorPosLabel)
-
     def setupMenubar(self):
         """
         Creates the Menubar with all Actions
@@ -801,7 +789,7 @@ class MainWindow(QMainWindow):
             try:
                 if isinstance(action.data()[0], str):
                     self.env.menuActions[action.data()[0]] = action
-            except:
+            except Exception:
                 pass
             if action.menu():
                 self.getMenuActions(action.menu())
@@ -1614,7 +1602,13 @@ class MainWindow(QMainWindow):
             self.autoSaveTimer.stop()
         for i in self.splitViewWidget.getAllTabWidgets():
             i.updateSettings(settings)
+        clearStatusBar(self.statusBar())
+        for i in settings.get("statusBarWidgetsLeft"):
+            self.statusBar().addWidget(self.env.statusBarWidgetDict[i]())
+        for i in settings.get("statusBarWidgetsRight"):
+            self.statusBar().addPermanentWidget(self.env.statusBarWidgetDict[i]())
         self.updateWindowTitle()
+        self.updateStatusBar()
 
     def updateWindowTitle(self):
         if self.env.settings.windowFileTitle:
@@ -1623,6 +1617,11 @@ class MainWindow(QMainWindow):
         else:
             self.setWindowTitle("jdTextEdit")
 
+    def updateStatusBar(self):
+        for i in self.statusBar().children():
+            if isinstance(i, StatusBarWidgetBase):
+                i.updateWidget(self)
+
     def saveSession(self):
         if not os.path.isdir(os.path.join(self.env.dataDir, "session_data")):
             os.mkdir(os.path.join(self.env.dataDir, "session_data"))
@@ -1665,7 +1664,7 @@ class MainWindow(QMainWindow):
         else:
             try:
                 os.remove(os.path.join(self.env.dataDir,"windowstate.json"))
-            except:
+            except Exception:
                 pass
         with open(os.path.join(self.env.dataDir, "lastversion.txt"), "w", encoding="utf-8") as f:
             f.write(self.env.version)
@@ -1690,7 +1689,7 @@ class MainWindow(QMainWindow):
     def removeTempOpenFile(self):
         try:
             os.remove(getTempOpenFilePath())
-        except:
+        except Exception:
             pass
 
     def dragEnterEvent(self, event):
